@@ -27,10 +27,6 @@ def send_report(codecov_reports):
     print(f"- Report contents will be visible here {view}")
     upload_to_s3_url = decode[1]
     print(f"- Sending contents to {upload_to_s3_url}")
-
-    print(decode)
     codecov_report = separator.join(codecov_reports) + separator
-
-    print(codecov_report)
     r = requests.put(upload_to_s3_url, headers=headers, data=codecov_report)
     return r.content.decode("utf-8")
